==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/insights/kotlin/inputs/DataSourceConfigurationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.insights.kotlin.inputs

import com.pulumi.azurenative.insights.inputs.DataSourceConfigurationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property eventLogs Windows event logs configuration.
 * @property perfCounters Performance counter configuration
 * @property providers ETW providers configuration
 */
public data class DataSourceConfigurationArgs(
    public val eventLogs: Output<List<EventLogConfigurationArgs>>? = null,
    public val perfCounters: Output<List<PerformanceCounterConfigurationArgs>>? = null,
    public val providers: Output<List<EtwProviderConfigurationArgs>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.insights.inputs.DataSourceConfigurationArgs> {
    override fun toJava(): com.pulumi.azurenative.insights.inputs.DataSourceConfigurationArgs =
        com.pulumi.azurenative.insights.inputs.DataSourceConfigurationArgs.builder()
            .eventLogs(
                eventLogs?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .perfCounters(
                perfCounters?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .providers(
                providers?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [DataSourceConfigurationArgs].
 */
@PulumiTagMarker
public class DataSourceConfigurationArgsBuilder internal constructor() {
    private var eventLogs: Output<List<EventLogConfigurationArgs>>? = null

    private var perfCounters: Output<List<PerformanceCounterConfigurationArgs>>? = null

    private var providers: Output<List<EtwProviderConfigurationArgs>>? = null

    /**
     * @param value Windows event logs configuration.
     */
    @JvmName("cgebrsafvmmvxgme")
    public suspend fun eventLogs(`value`: Output<List<EventLogConfigurationArgs>>) {
        this.eventLogs = value
    }

    @JvmName("kobxhnnfxykgicwa")
    public suspend fun eventLogs(vararg values: Output<EventLogConfigurationArgs>) {
        this.eventLogs = Output.all(values.asList())
    }

    /**
     * @param values Windows event logs configuration.
     */
    @JvmName("ifnafonlvgkrbpho")
    public suspend fun eventLogs(values: List<Output<EventLogConfigurationArgs>>) {
        this.eventLogs = Output.all(values)
    }

    /**
     * @param value Performance counter configuration
     */
    @JvmName("wrpcsounnenwmolm")
    public suspend fun perfCounters(`value`: Output<List<PerformanceCounterConfigurationArgs>>) {
        this.perfCounters = value
    }

    @JvmName("lvgapqjsgdsvqwfv")
    public suspend fun perfCounters(vararg values: Output<PerformanceCounterConfigurationArgs>) {
        this.perfCounters = Output.all(values.asList())
    }

    /**
     * @param values Performance counter configuration
     */
    @JvmName("qwdbaesbiuobqyli")
    public suspend fun perfCounters(values: List<Output<PerformanceCounterConfigurationArgs>>) {
        this.perfCounters = Output.all(values)
    }

    /**
     * @param value ETW providers configuration
     */
    @JvmName("smsowswthbxmteot")
    public suspend fun providers(`value`: Output<List<EtwProviderConfigurationArgs>>) {
        this.providers = value
    }

    @JvmName("nbjydpvebplqgsro")
    public suspend fun providers(vararg values: Output<EtwProviderConfigurationArgs>) {
        this.providers = Output.all(values.asList())
    }

    /**
     * @param values ETW providers configuration
     */
    @JvmName("uajbxcpvwalvcune")
    public suspend fun providers(values: List<Output<EtwProviderConfigurationArgs>>) {
        this.providers = Output.all(values)
    }

    /**
     * @param value Windows event logs configuration.
     */
    @JvmName("fcsqyqiaslkpdddv")
    public suspend fun eventLogs(`value`: List<EventLogConfigurationArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.eventLogs = mapped
    }

    /**
     * @param argument Windows event logs configuration.
     */
    @JvmName("ygoewycvuwyrcfej")
    public suspend
    fun eventLogs(argument: List<suspend EventLogConfigurationArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            EventLogConfigurationArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.eventLogs = mapped
    }

    /**
     * @param argument Windows event logs configuration.
     */
    @JvmName("xeyfpqupjduiadfg")
    public suspend fun eventLogs(
        vararg
        argument: suspend EventLogConfigurationArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            EventLogConfigurationArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.eventLogs = mapped
    }

    /**
     * @param argument Windows event logs configuration.
     */
    @JvmName("scjyaptdhrtfqatw")
    public suspend fun eventLogs(argument: suspend EventLogConfigurationArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(EventLogConfigurationArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.eventLogs = mapped
    }

    /**
     * @param values Windows event logs configuration.
     */
    @JvmName("qxrqlcxlfenevree")
    public suspend fun eventLogs(vararg values: EventLogConfigurationArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.eventLogs = mapped
    }

    /**
     * @param value Performance counter configuration
     */
    @JvmName("fekfbuqoiexxweek")
    public suspend fun perfCounters(`value`: List<PerformanceCounterConfigurationArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.perfCounters = mapped
    }

    /**
     * @param argument Performance counter configuration
     */
    @JvmName("tikdmchlmvxkqooh")
    public suspend
    fun perfCounters(argument: List<suspend PerformanceCounterConfigurationArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            PerformanceCounterConfigurationArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.perfCounters = mapped
    }

    /**
     * @param argument Performance counter configuration
     */
    @JvmName("cnbflsxeroyxfpdj")
    public suspend fun perfCounters(
        vararg
        argument: suspend PerformanceCounterConfigurationArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            PerformanceCounterConfigurationArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.perfCounters = mapped
    }

    /**
     * @param argument Performance counter configuration
     */
    @JvmName("rgfmpwqeugqbbupk")
    public suspend
    fun perfCounters(argument: suspend PerformanceCounterConfigurationArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            PerformanceCounterConfigurationArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.perfCounters = mapped
    }

    /**
     * @param values Performance counter configuration
     */
    @JvmName("eoygvtuljgcuqcss")
    public suspend fun perfCounters(vararg values: PerformanceCounterConfigurationArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.perfCounters = mapped
    }

    /**
     * @param value ETW providers configuration
     */
    @JvmName("elygrounhqafkqej")
    public suspend fun providers(`value`: List<EtwProviderConfigurationArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.providers = mapped
    }

    /**
     * @param argument ETW providers configuration
     */
    @JvmName("ggxmglmsrymgmxys")
    public suspend
    fun providers(argument: List<suspend EtwProviderConfigurationArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            EtwProviderConfigurationArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.providers = mapped
    }

    /**
     * @param argument ETW providers configuration
     */
    @JvmName("fajttgxjdmjmhgte")
    public suspend fun providers(
        vararg
        argument: suspend EtwProviderConfigurationArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            EtwProviderConfigurationArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.providers = mapped
    }

    /**
     * @param argument ETW providers configuration
     */
    @JvmName("pqwqmrecwvkfvaxy")
    public suspend fun providers(argument: suspend EtwProviderConfigurationArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            EtwProviderConfigurationArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.providers = mapped
    }

    /**
     * @param values ETW providers configuration
     */
    @JvmName("ohltlhaxlfolvydr")
    public suspend fun providers(vararg values: EtwProviderConfigurationArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.providers = mapped
    }

    internal fun build(): DataSourceConfigurationArgs = DataSourceConfigurationArgs(
        eventLogs = eventLogs,
        perfCounters = perfCounters,
        providers = providers,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/insights/kotlin/inputs/DataSourceConfigurationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.insights.kotlin.inputs

import com.pulumi.azurenative.insights.inputs.DataSourceConfigurationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property eventLogs Windows event logs configuration.
 * @property perfCounters Performance counter configuration
 * @property providers ETW providers configuration
 */
public data class DataSourceConfigurationArgs(
    public val eventLogs: Output<List<EventLogConfigurationArgs>>? = null,
    public val perfCounters: Output<List<PerformanceCounterConfigurationArgs>>? = null,
    public val providers: Output<List<EtwProviderConfigurationArgs>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.insights.inputs.DataSourceConfigurationArgs> {
    override fun toJava(): com.pulumi.azurenative.insights.inputs.DataSourceConfigurationArgs =
        com.pulumi.azurenative.insights.inputs.DataSourceConfigurationArgs.builder()
            .eventLogs(
                eventLogs?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .perfCounters(
                perfCounters?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .providers(
                providers?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [DataSourceConfigurationArgs].
 */
@PulumiTagMarker
public class DataSourceConfigurationArgsBuilder internal constructor() {
    private var eventLogs: Output<List<EventLogConfigurationArgs>>? = null

    private var perfCounters: Output<List<PerformanceCounterConfigurationArgs>>? = null

    private var providers: Output<List<EtwProviderConfigurationArgs>>? = null

    /**
     * @param value Windows event logs configuration.
     */
    @JvmName("bskrcrxmwftodbnu")
    public suspend fun eventLogs(`value`: Output<List<EventLogConfigurationArgs>>) {
        this.eventLogs = value
    }

    @JvmName("xucwjfqpiavdxpor")
    public suspend fun eventLogs(vararg values: Output<EventLogConfigurationArgs>) {
        this.eventLogs = Output.all(values.asList())
    }

    /**
     * @param values Windows event logs configuration.
     */
    @JvmName("hkjnuduvvptcknhp")
    public suspend fun eventLogs(values: List<Output<EventLogConfigurationArgs>>) {
        this.eventLogs = Output.all(values)
    }

    /**
     * @param value Performance counter configuration
     */
    @JvmName("ehxyqoxfbofoaoaq")
    public suspend fun perfCounters(`value`: Output<List<PerformanceCounterConfigurationArgs>>) {
        this.perfCounters = value
    }

    @JvmName("qyfswosgrjvlppqh")
    public suspend fun perfCounters(vararg values: Output<PerformanceCounterConfigurationArgs>) {
        this.perfCounters = Output.all(values.asList())
    }

    /**
     * @param values Performance counter configuration
     */
    @JvmName("btqhsdhwdpspyxqf")
    public suspend fun perfCounters(values: List<Output<PerformanceCounterConfigurationArgs>>) {
        this.perfCounters = Output.all(values)
    }

    /**
     * @param value ETW providers configuration
     */
    @JvmName("xgwymbjkwebebbsk")
    public suspend fun providers(`value`: Output<List<EtwProviderConfigurationArgs>>) {
        this.providers = value
    }

    @JvmName("thyvrawvgxigyfbh")
    public suspend fun providers(vararg values: Output<EtwProviderConfigurationArgs>) {
        this.providers = Output.all(values.asList())
    }

    /**
     * @param values ETW providers configuration
     */
    @JvmName("ulksbgvrgnuavafh")
    public suspend fun providers(values: List<Output<EtwProviderConfigurationArgs>>) {
        this.providers = Output.all(values)
    }

    /**
     * @param value Windows event logs configuration.
     */
    @JvmName("cwkuwcanuqinnpni")
    public suspend fun eventLogs(`value`: List<EventLogConfigurationArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.eventLogs = mapped
    }

    /**
     * @param argument Windows event logs configuration.
     */
    @JvmName("euaoqvvjrucgvfjw")
    public suspend
    fun eventLogs(argument: List<suspend EventLogConfigurationArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            EventLogConfigurationArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.eventLogs = mapped
    }

    /**
     * @param argument Windows event logs configuration.
     */
    @JvmName("gxfvfsvvdujphlmu")
    public suspend fun eventLogs(
        vararg
        argument: suspend EventLogConfigurationArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            EventLogConfigurationArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.eventLogs = mapped
    }

    /**
     * @param argument Windows event logs configuration.
     */
    @JvmName("ptuyuwrbthbcxecl")
    public suspend fun eventLogs(argument: suspend EventLogConfigurationArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(EventLogConfigurationArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.eventLogs = mapped
    }

    /**
     * @param values Windows event logs configuration.
     */
    @JvmName("jovedwyjlmqsqhgg")
    public suspend fun eventLogs(vararg values: EventLogConfigurationArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.eventLogs = mapped
    }

    /**
     * @param value Performance counter configuration
     */
    @JvmName("sfrybvwbevburdxr")
    public suspend fun perfCounters(`value`: List<PerformanceCounterConfigurationArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.perfCounters = mapped
    }

    /**
     * @param argument Performance counter configuration
     */
    @JvmName("xgtrkfwsoxuoheor")
    public suspend
    fun perfCounters(argument: List<suspend PerformanceCounterConfigurationArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            PerformanceCounterConfigurationArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.perfCounters = mapped
    }

    /**
     * @param argument Performance counter configuration
     */
    @JvmName("pftvkofceyscljdr")
    public suspend fun perfCounters(
        vararg
        argument: suspend PerformanceCounterConfigurationArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            PerformanceCounterConfigurationArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.perfCounters = mapped
    }

    /**
     * @param argument Performance counter configuration
     */
    @JvmName("uxpqijceduqynmqf")
    public suspend
    fun perfCounters(argument: suspend PerformanceCounterConfigurationArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            PerformanceCounterConfigurationArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.perfCounters = mapped
    }

    /**
     * @param values Performance counter configuration
     */
    @JvmName("rxutvssgvqcrqrst")
    public suspend fun perfCounters(vararg values: PerformanceCounterConfigurationArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.perfCounters = mapped
    }

    /**
     * @param value ETW providers configuration
     */
    @JvmName("unjovfmglxvtxjxf")
    public suspend fun providers(`value`: List<EtwProviderConfigurationArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.providers = mapped
    }

    /**
     * @param argument ETW providers configuration
     */
    @JvmName("sdpckcxjtcuytwdb")
    public suspend
    fun providers(argument: List<suspend EtwProviderConfigurationArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            EtwProviderConfigurationArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.providers = mapped
    }

    /**
     * @param argument ETW providers configuration
     */
    @JvmName("fyndniiygdfrjjuk")
    public suspend fun providers(
        vararg
        argument: suspend EtwProviderConfigurationArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            EtwProviderConfigurationArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.providers = mapped
    }

    /**
     * @param argument ETW providers configuration
     */
    @JvmName("jdwdusoxhqmrfjjf")
    public suspend fun providers(argument: suspend EtwProviderConfigurationArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            EtwProviderConfigurationArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.providers = mapped
    }

    /**
     * @param values ETW providers configuration
     */
    @JvmName("kobnmtnjeswvidbx")
    public suspend fun providers(vararg values: EtwProviderConfigurationArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.providers = mapped
    }

    internal fun build(): DataSourceConfigurationArgs = DataSourceConfigurationArgs(
        eventLogs = eventLogs,
        perfCounters = perfCounters,
        providers = providers,
    )
}
